% Plots the n roots of unity on an Argand diagram.
% i.e. complex numbers which are the solution to the equation z^n = 1
function nth_roots_of_unity
fsize = 18; %Fontsize

%Display message to command window
disp(' ')
disp(' %%%%%%%%%%%%%%%%%%%%%%%%%%%% ')
disp('  Nth Roots of Unity Plotter')
disp(' %%%%%%%%%%%%%%%%%%%%%%%%%%%% ')
disp(' ')

%Get N from user
disp(' Set N such that z^N = 1, where z is a complex number.' )
N = input(' > N = ');
if isempty(N)
    N = 12;
    disp(' N = 12 is the default option ')
end
disp(' ');

%Plot solutions to z^N = 1 on an Argand Diagram
figure( 'name', 'Argand diagram', 'color', [1 1 1] );
axes('nextplot','add','fontsize',fsize)
for nn=1:N
    z = exp( 1i*2*pi*(nn-1)/N );
    plot( real(z), imag(z), 'r*','markersize', fsize );
    plot( [0,real(z)],[0,imag(z)],'r-' );
    if imag(z)<0
        imag_sign = ' - ';
    else
        imag_sign = ' + ';
    end
    disp([' z',num2str(nn),' = ',...
        num2str(real(z)),imag_sign,num2str(abs(imag(z))),'i']);
end
disp(' ');
grid on; axis equal; box on
title_str = ['Solutions to z^{',num2str(N),'} = 1'];
xlabel( 'x = Re(z)' ); ylabel( 'y = Im(z)' ); title( title_str )

%Remove { } from title_str (this is used to make powers look correct in
%title)
title_str = strrep( title_str, '{','' );
title_str = strrep( title_str, '}','' );

%Print .png file of graph
print( gcf, [title_str,'.png'],'-dpng','-r300' );

%End of code