%juliafunction
% Defines iterative complex mapping of matrix z.
%
% Syntax: z=juliafunction(z,z0,index)
%
% z       - Matrix of complex numbers
% z0      - Matrix of complex numbers, same size as z
%           z0 is typically the coordinates describing the argand diagram
%           upon which z is plotted.
% index   - Matrix of size of z which gives the index of the elements of z
%           relative to the original map z0. Note z and index may be smaller
%           in size than z0
% funcstr - String describing julia function i.e. 'z^2 +z0(index)' for a
%           Mandlebrot set.

function z=juliafunction(z,z0,index,funcstr)

%Replace *, / and ^ symbols by . to enable element-wise matrix computation
%within julia.
funcstr=strrep(funcstr,'*','.*');
funcstr=strrep(funcstr,'/','./');
funcstr=strrep(funcstr,'^','.^');

%Append z0 with index to enable z to be synamically resized by julia.
funcstr = strrep(funcstr,'z0','z0(index)');

%Evaluate function
try
    eval(['z=',funcstr,';']);
catch
    errordlg('Syntax error in julia function. Try again!', 'julia error!')
    z=[];
    return
end

%End of code