%Plots the first N points of a Mandlebrot iteration in the complex plane

z0 = 0.2 + 0.5*i;  %Starting point in the Argand diagram
N = 50; %Number of iterations
fsize = 18;  %Fontsiz eand markersize

%Perform iteration
z = z0;
for n=1:N-1
    z(n+1) = z(n)^2 + z0;
end

%Plot 'trajectory' in the Argand diagram
figure('units','normalized','position',[0 0 1 1]);
plot( real(z), imag(z),'r-*' ); hold on;
plot( real(z0), imag(z0),'g*','markersize',fsize );
grid on; box on; axis equal; set(gca,'fontsize',fsize);
xlabel('Re(z)'); ylabel('Im(z)');
title(['First ',num2str(N),...
    ' iterations of z_{n+1} = z_n^2 +z_0.   z_0=',num2str(z0)]);

%Print screen
print(gcf,['mandletraj z0=',strrep(num2str(z0),'.','p'),'.png'],...
    '-dpng','-r300');

%End of code